#!/bin/bash -x
    set -x
    cd $HOME
    mkdir x32
    cd x32
    export X32=$PWD
    export cpu_count=6
    export svn_checkout="checkout --config-option config:miscellany:use-commit-times=yes"
#
#-------->>> use this env variable for pdcurses Release 4.3.5
#
    export svn_pdcurses="https://github.com/Bill-Gray/PDCursesMod.git/tags/v4.3.5 pdcurses-r435"
#
#-------->>> use this env variable for pdcurses TRUNK
#
#   export svn_pdcurses="https://github.com/Bill-Gray/PDCursesMod.git/trunk pdcurses-trunk"
#
#
#
#-------->>> use this env variable for GNUCOBOL most current commit
#
    export svn_gnucobol="svn://svn.code.sf.net/p/gnucobol/code/branches/gnucobol-3.x  gnucobol"
#
#-------->>> use this env variable for a specific commit of GNUCBOBOL
#-------->>> change "nnnn" to the commit you wish to download
#
#   export svn_gnucobol="-r nnnn svn://svn.code.sf.net/p/gnucobol/code/branches/gnucobol-3.x  gnucobol"
#
#-------->>> use this env variable for a specific RELEASE of GNUCBOBOL
#-------->>> change the tags name to the one you wish to download
#-------->>>            check in svn to check the actual tagname
#
#   export svn_gnucobol="svn://svn.code.sf.net/p/gnucobol/code/tags/gnucobol-3.2-preview  gnucobol-release"
#
#
#
#-------->>> use this env variable for GCSORT most current commit
#
    export svn_gcsort="https://svn.code.sf.net/p/gnucobol/contrib/trunk/tools/GCSORT  gcsort"
#
#-------->>> use this env variable for a specific commit of GNUCBOBOL
#-------->>> change "nnnn" to the commit you wish to download
#
#   export svn_gcsort="-r nnnn https://svn.code.sf.net/p/gnucobol/contrib/trunk/tools/GCSORT  gcsort"
#
#
#
# ==> this function builds pdcursesmod from the most current
#     source code. Note that it builds both WINCON & WINGUI
#
200_build_pdcurses () {
cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  pd*
    svn $svn_checkout $svn_pdcurses
#
#  ---> now repeat for WINGUI
#
    cd $X32
    cd pdc*/wingui      # note changes
    make -j$cpu_count -f Makefile INFOEX=Y CHTYPE_64=Y DLL=Y
    cp pdcurses.dll pdcurses-wingui.dll
    ls *.dll
    install pdcurses*.dll /mingw32/bin/.
    install pdcurses.a /mingw32/lib/libpdcurses.a
#
#  ---> now repeat for WINCON
#
    cd $X32
    cd pdc*/wincon      # note changes
    make -j$cpu_count -f Makefile INFOEX=Y CHTYPE_64=Y DLL=Y
    cp pdcurses.dll pdcurses-wincon.dll
    ls *.dll
    install pdcurses*.dll /mingw32/bin/.
    install pdcurses.a /mingw32/lib/libpdcurses.a
#
#  first we need to prepend the following 4 lines to curses.h
#
    cd ..
    echo "/* defines matching the creation of the library */ " >  temp.txt
    echo "/* Arnold J. Trembley, 2022-05-29-Sun           */ " >> temp.txt
    echo "#define CHTYPE_64                                  " >> temp.txt
    echo "#define PDC_DLL_BUILD                              " >> temp.txt
    cat  curses.h                                              >> temp.txt
#
    cp temp.txt curses.h
#
#  display the contents of curses.h to ensure that it is correct.
#
    head curses.h
    tail curses.h
    cp curses.h pdcurses.h
    install *.h /mingw32/include/.
#
    echo " Done installing PDCursesMOD-4.3.5 !! "
#
}

#
#
# ==> this function builds VBISAM 2.1.1 from Ron Normans website
#
300_build_vbisam_db () {
cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  vbi*
    wget https://rjnorman74.users.sourceforge.net/vbisam-2.1.1.tar.Z
    zcat *.Z | tar -xvf -
    rm vbi*.Z
    cd vbisam*
    ./configure --prefix=/mingw32 --disable-static --enable-shared --with-compatcisam
#   sed -i.bak -e "s/\(allow_undefined=\)yes/\1no/" libtool
    make -j$cpu_count
    make -j$cpu_count check
    make  install
    ls /mingw32/bin/libvbi*.*
    ls /mingw32/include/vbi*.*
#
    echo " Done installing VBISAM 2.2   !! "
#
}

#
# ==> this function builds GNUCOBOL 3.2dev from the most current
#     source code.
#
400_build_gnucobol () {
    cd $X32
    # ----> first remove existing directory for HOME
    rm -f -r  gnu*
    svn $svn_checkout $svn_gnucobol
    cd gnu*
    cd libcob
    cp  /F/Downloads/gnucobol-4844/libcob/intrinsic.c  intrinsic.c
    pwd
#   wget https://raw.githubusercontent.com/DaveGamble/cJSON/master/cJSON.h
#   wget https://raw.githubusercontent.com/DaveGamble/cJSON/master/cJSON.c
    cd ..
    cd tests/cobol85
    wget https://sourceforge.net/projects/gnucobol/files/nist/newcob.val.tar.gz
    tar xzf newcob.val.tar.gz
    rm newcob.val.tar.gz
    cd $X32
    cd gnu*
#
    ./autogen.sh install
#
    ./configure -prefix=/mingw32 -with-vbisam --disable-rpath --with-curses=pdcurses
    make -j$cpu_count                                          # Build the GnuCOBOL compiler
    make  check TESTSUITEFLAGS="--jobs=$cpu_count"             # Test the GnuCOBOL build
    make  -j$cpu_count test                                    # Run NIST COBOL 85 test suite
    make  install                                     # Prepare Install format
#
    echo " Done installing GNUCOBOL 3.2dev !! "
#
}

#
# ==> this function builds GCSORT from the most current
#     source code.
#
500_build_gcsort   () {
    cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  gcsort*
    svn $svn_checkout $svn_gcsort
    cd gcsort*

#
    wget https://www.arnoldtrembley.com/cobenv.zip
    unzip -o cobenv.zip -d /mingw32/bin
    rm -f -r  cobenv.zip
#
# ====>>>> setup cobol environment
    source cobenv.sh --setenv
    cobc --info
    cobcrun --info
#
    cd $X32
    cd gcsort*
    make -j$cpu_count
    gcsort --version
    cp gcsort.exe  /mingw32/bin
    cd tests/script/
    ./compile.sh
    cd $X32
    cd gcsort*
    cd tests/bin
    ls -l
    export COB_PRE_LOAD=gctestgetop.so
    for varname in ${!COB*};
        do      echo $varname is ${!varname} ;
    done
    ./gctestset.exe
    ls -l
    ./gctestrun 1>log_run.log 2>log_run_err.log
    tail -n 20 log_run.log 
#  
# ====> copy gcsort.exe to the gnucobol distribution folders...
#
    cp  /mingw32/bin/gcsort.exe  /home/spcwh2/x32/gnucobol/GnuCOBOL_mingw/bin
    cp  /mingw32/bin/gcsort.exe  /home/spcwh2/x32/gnucobol/GnuCOBOL_mingw_dbg/bin
#
echo " Done installing GCSORT !! "
#
}

#   call function to build toolchain dependencies
start_time=$(date)
echo "@@start time      $start_time"
#
#   call function to build pdcursesmod
    200_build_pdcurses
    pdcurses_time=$(date)
    echo "@@pdcurses        $pdcurses_time"
#
#   call function to build vbisam db
    300_build_vbisam_db
    vbisam_time=$(date)
    echo "@@vbisam          $vbisam_time"
#
#   call function to build gnucobol
    400_build_gnucobol
    gnucobol_time=$(date)
    echo "@@gnucobol        $gnucobol_time"
#
#   call function to build gcsort
    500_build_gcsort
    gcsort_time=$(date)
    echo "@@gcsort          $gcsort_time"

    echo "@@start time      $start_time"
    echo "@@toolchain       $toolchain_time"
    echo "@@pdcurses        $pdcurses_time"
    echo "@@vbisam          $vbisam_time"
    echo "@@gnucobol        $gnucobol_time"
    echo "@@gcsort          $gcsort_time"


echo " "
echo " "
echo "@@start time      $start_time"        >  $X32/runtime.txt
echo "@@pdcurses        $pdcurses_time"     >> $X32/runtime.txt
echo "@@vbisam          $vbisam_time"     >> $X32/runtime.txt
echo "@@gnucobol        $gnucobol_time"     >> $X32/runtime.txt
echo "@@gcsort          $gcsort_time"       >> $X32/runtime.txt

