#!/bin/bash -x
    set -x
    cd $HOME
    mkdir x32
    cd x32
    export X32=$PWD
#
    export cpu_count=4
    export svn_checkout="checkout"
#
#-------->>> use this env variable for pdcurses Release 4.3.5
#
    export svn_pdcurses="https://github.com/Bill-Gray/PDCursesMod.git/tags/v4.3.5 pdcurses-r435"
#
#-------->>> use this env variable for pdcurses TRUNK
#
#   export svn_pdcurses="https://github.com/Bill-Gray/PDCursesMod.git/trunk pdcurses-trunk"
#
#
#
#
#-------->>> use this env variable for GNUCOBOL most current commit
#
    export svn_gnucobol="svn://svn.code.sf.net/p/gnucobol/code/branches/gnucobol-3.x  gnucobol"
#
#-------->>> use this env variable for a specific commit of GNUCBOBOL
#-------->>> change "nnnn" to the commit you wish to download
#
#   export svn_gnucobol="-r nnnn svn://svn.code.sf.net/p/gnucobol/code/branches/gnucobol-3.x  gnucobol"
#
#
#-------->>> use this env variable for a specific RELEASE of GNUCBOBOL
#-------->>> change the tags name to the one you wish to download
#-------->>>            check in svn to check the actual tagname
#
#   export svn_gnucobol="svn://svn.code.sf.net/p/gnucobol/code/tags/gnucobol-3.2-preview  gnucobol-release"
#
#
#
#-------->>> use this env variable for GCSORT most current commit
#
    export svn_gcsort="https://svn.code.sf.net/p/gnucobol/contrib/trunk/tools/GCSORT  gcsort"
#
#-------->>> use this env variable for a specific commit of GNUCBOBOL
#-------->>> change "nnnn" to the commit you wish to download
#
#   export svn_gcsort="-r nnnn https://svn.code.sf.net/p/gnucobol/contrib/trunk/tools/GCSORT  gcsort"
#
#
#
# build_x32.sh
# Shell script for building GNUCOBOL
# in MSYS2 MINGW32/mingw32
#
#
# ==> this function builds pdcursesmod from the most current
#     source code. Note that it builds both WINCON & WINGUI
#
200_build_pdcurses () {
    cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  pd*
    svn $svn_checkout $svn_pdcurses
#
#  ---> now repeat for WINGUI
#
    cd $X32
    cd pdc*/wingui      # note changes
    make -j$cpu_count -f Makefile INFOEX=Y CHTYPE_64=Y DLL=Y
    cp pdcurses.dll pdcurses-wingui.dll
    ls *.dll
    install pdcurses*.dll /mingw32/bin/.
    install pdcurses.a /mingw32/lib/libpdcurses.a
#
#  ---> now repeat for WINCON
#
    cd $X32
    cd pdc*/wincon      # note changes
    make -j$cpu_count -f Makefile INFOEX=Y CHTYPE_64=Y DLL=Y
    cp pdcurses.dll pdcurses-wincon.dll
    ls *.dll
    install pdcurses*.dll /mingw32/bin/.
    install pdcurses.a /mingw32/lib/libpdcurses.a
#
#  first we need to prepend the following 4 lines to curses.h
#
    cd ..
    echo "/* defines matching the creation of the library */ " >  temp.txt
    echo "/* Arnold J. Trembley, 2022-05-29-Sun           */ " >> temp.txt
    echo "#define CHTYPE_64                                  " >> temp.txt
    echo "#define PDC_DLL_BUILD                              " >> temp.txt
    cat  curses.h                                              >> temp.txt
#
    cp temp.txt curses.h
#
#  display the contents of curses.h to ensure that it is correct.
#
    head curses.h
    tail curses.h
    cp curses.h pdcurses.h
    install *.h /mingw32/include/.
#
    echo " Done installing PDCursesMOD-4.3.4 !! "
#
}

#
# ==> this function builds Berkeley DB 18.1.40 from the most current
#     source code.
#
300_build_berkeley_db () {
    cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  db*
    wget https://download.oracle.com/berkeley-db/db-18.1.40.tar.gz
    tar xzf db*.tar.gz
    rm db*.tar.gz
    cd db*/src/os_windows
    cp os_stat.c os_stat.bak
    sed -i 's/_tcsclen/strlen/' os_stat.c
#
    cd $X32
    cd db*/build_unix
    ../dist/configure --enable-mingw --prefix=/mingw32 --enable-compat185 --with-mutex=x86/gcc-assembly --with-cryptography=no --enable-sql --enable-sql_compat
    make -j$cpu_count
    make install
    ls /mingw32/bin/libdb*.dll
#
    echo " Done installing Berkeley DB 18.1 !! "
#
}

#
# ==> this function builds GNUCOBOL 3.2dev from the most current
#     source code.
#
400_build_gnucobol () {
    cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  gnu*
    svn $svn_checkout $svn_gnucobol
    cd gnu*
    cd libcob
    pwd
#   wget https://raw.githubusercontent.com/DaveGamble/cJSON/master/cJSON.h
#   wget https://raw.githubusercontent.com/DaveGamble/cJSON/master/cJSON.c
    cd ..
    cd tests/cobol85
    wget https://sourceforge.net/projects/gnucobol/files/nist/newcob.val.tar.gz
    tar xzf newcob.val.tar.gz
    rm newcob.val.tar.gz
    cd $X32
    cd gnu*
#
#   cp /F/AA-minGW32-static/create_mingw_bindist.sh ./build_aux
#
    ./autogen.sh install
#
    ./configure -prefix=/mingw32 -with-db --disable-rpath --with-curses=pdcurses PERL=/usr/bin/perl
    make -j$cpu_count                                               # Build the GnuCOBOL compiler
    make -j$cpu_count dist -C po                                    # Build translations
    make check TESTSUITEFLAGS="--jobs=$cpu_count"                   # Test the GnuCOBOL build
    make -j$cpu_count test PERL=/usr/bin/perl  COB_UNIX_LF=Y        # Run NIST COBOL 85 test suite
    make install                                                    # Prepare Install format
    make distmingw
    cd GnuCOBOL_mingw
    curl -Lko gnucobol.pdf "https://ci.appveyor.com/api/projects/GitMensch/gnucobol-3-x/artifacts/doc/gnucobol.pdf?job=Image:%20Ubuntu2004"
    rm bin/cobenv.*
    rm bin/build*.sh
    cd ..
    cd GnuCOBOL_mingw_dbg
    curl -Lko gnucobol.pdf "https://ci.appveyor.com/api/projects/GitMensch/gnucobol-3-x/artifacts/doc/gnucobol.pdf?job=Image:%20Ubuntu2004"
    rm bin/cobenv.*
    rm bin/build*.sh
#
    echo " Done installing GNUCOBOL 3.2dev !! "
#
}

#
# ==> this function builds GCSORT from the most current
#     source code.
#
500_build_gcsort   () {
    cd $X32
# ----> first remove existing directory for HOME
    rm -f -r  gcsort*
    svn $svn_checkout $svn_gcsort
    cd gcsort*

#
    wget https://www.arnoldtrembley.com/cobenv.zip
    unzip -o cobenv.zip -d /mingw32/bin
    rm -f -r  cobenv.zip
# ====>>>> setup cobol environment
    source cobenv.sh --setenv
    cobc --info
    cobcrun --info
#
    cd $X32
    cd gcsort*
    make -j$cpu_count
    gcsort --version
    cp gcsort.exe  /mingw32/bin
    cd tests/script/
    ./compile.sh
    cd $X32
    cd gcsort*
    cd tests/bin
    ls -l
    export COB_PRE_LOAD=gctestgetop.so
    for varname in ${!COB*};
        do      echo $varname is ${!varname} ;
    done
    ./gctestset.exe
    ls -l
    ./gctestrun 1>log_run.log 2>log_run_err.log
    tail log_run.log -n 20
#
# ====> copy gcsort.exe to the gnucobol distribution folders...
#
    cp  /mingw32/bin/gcsort.exe  /home/spcwh2/x32/gnucobol/GnuCOBOL_mingw/bin
    cp  /mingw32/bin/gcsort.exe  /home/spcwh2/x32/gnucobol/GnuCOBOL_mingw_dbg/bin
#
echo " Done installing GCSORT !! "
#
}

#   call function to build toolchain dependencies
    start_time=$(date)
    echo "@@start time      $start_time"
#
#       call function to build pdcursesmod
    200_build_pdcurses
    pdcurses_time=$(date)
    echo "@@pdcurses        $pdcurses_time"
#
#       call function to build berkeley db
    300_build_berkeley_db
    berkeley_time=$(date)
    echo "@@berkeley        $berkeley_time"
#
#       call function to build gnucobol
    400_build_gnucobol
    gnucobol_time=$(date)
    echo "@@gnucobol        $gnucobol_time"
#
#       call function to build gcsort
    500_build_gcsort
    gcsort_time=$(date)
    echo "@@gcsort          $gcsort_time"

    echo "@@start time      $start_time"
    echo "@@toolchain       $toolchain_time"
    echo "@@pdcurses        $pdcurses_time"
    echo "@@berkeley        $berkeley_time"
    echo "@@gnucobol        $gnucobol_time"
    echo "@@gcsort          $gcsort_time"


    echo "@@start time      $start_time"        >  $X32/runtime.txt
    echo "@@toolchain       $toolchain_time"    >> $X32/runtime.txt
    echo "@@pdcurses        $pdcurses_time"     >> $X32/runtime.txt
    echo "@@berkeley        $berkeley_time"     >> $X32/runtime.txt
    echo "@@gnucobol        $gnucobol_time"     >> $X32/runtime.txt
    echo "@@gcsort          $gcsort_time"       >> $X32/runtime.txt

